discoIPC
===========================

Connect to the local Discord IPC Socket, for features like `Rich
Presence`_.

|GitHub release| |Known Vulnerabilities| |license| |Say Thanks!|

Installation
------------

This is a `Python`_ module available through the `PyPI`_.

Before installing, `download and install Python`_. We recommend
installing version 3.5+ of Python.

Installation is done using the ``pip install`` command:

.. code:: bash

    $ pip install discoIPC

For more info, see `pip install`_ docs.

Get Started
-----------

Read the `Wiki`_ to see the available classes and methods and
know how to use them.

Links
-----------

-  `Discord Rich Presence Website`_
-  `Discord Developer Documentation`_
-  `Official Discord RPC Bindings`_

Contributors
------------

The developer of the `discoIPC`_ package is `k3rn31p4nic`_

`List of all contributors`_


License
-------

`GPL-3.0`_

    If you liked this project you can **⭐ Star** it on `GitHub`_ to show
    your love.

.. _Python: https://python.org
.. _PyPI: https://pypi.python.org/
.. _download and install Python: https://www.python.org/downloads/
.. _pip install: https://docs.python.org/3/installing/index.html
.. _Wiki: https://github.com/k3rn31p4nic/discoIPC/wiki
.. _Rich Presence: https://discordapp.com/rich-presence
.. _Discord Rich Presence Website: https://discordapp.com/rich-presence
.. _Discord Developer Documentation: https://discordapp.com/developers
.. _Official Discord RPC Bindings: https://github.com/discordapp/discord-rpc
.. _k3rn31p4nic: https://sankarsankampa.com
.. _List of all contributors: https://github.com/k3rn31p4nic/discoIPC/graphs/contributors
.. _GPL-3.0: https://github.com/k3rn31p4nic/discoIPC/blob/master/LICENSE.txt
.. _GitHub: https://github.com/k3rn31p4nic/discoIPC

.. |GitHub release| image:: https://img.shields.io/github/release/k3rn31p4nic/discoIPC.svg?style=flat
   :target: https://github.com/k3rn31p4nic/discoIPC/releases
.. |license| image:: https://img.shields.io/github/license/k3rn31p4nic/discoIPC.svg
   :target: LICENSE
.. |Known Vulnerabilities| image:: https://snyk.io/test/github/k3rn31p4nic/discoIPC/badge.svg
   :target: https://snyk.io/test/github/k3rn31p4nic/discoIPC
.. |Say Thanks!| image:: https://img.shields.io/badge/Say%20Thanks-!-1EAEDB.svg
   :target: https://saythanks.io/to/k3rn31p4nic
